#!/bin/bash

# cd to directory of this script
cd "`echo $0 | perl -pe 's|/[^/]+$||'`"

# insert tag text
insert () {
  perl -p -e "s|<-$1->|$2|"
}

# output title
output () {
  multimarkdown -c | cat head - foot | insert title "$1"
}

# materials
materials () {
   cd ../pdf
   # use 01, 02, ... subdirectories to determine order
   for dir in *
   do
      cd "${dir}"
      for file in *
      do
         name="`echo ${file} | perl -pe 's|.pdf$||'`"
         echo "* [${name}](pdf/${dir}/${file})"
      done
      cd ..
   done   
}

# prepare calendar table
calendar=$(./calendar.py calendar.txt)

# calendar.html
cat calendar.md |\
   insert calendar "${calendar}" |\
   output "$(cat title) (Calendar)" > ../calendar.html

# index.html
cat index.md |\
   insert materials "$(materials)" |\
   insert calendar "${calendar}" |\
   output "$(cat title)" > ../index.html

# source.html
cat source.md |\
   output "$(cat title) (Page Sources)" > ../source.html

# links.html
cat links.md |\
   output "$(cat title) (Links)" > ../links.html

# create tarball
cd ..
tar -czf source.tar.gz source

# testing
if [ `uname` = "Darwin" ]
then
   open index.html
#  open source.html
#  open links.html
fi
